@@ -8,7 +8,7 @@ import click
 from configobj import ConfigObj
 
 
-__version__ = "0.0.3"
+__version__ = "0.1.0"
 
 DEFAULT_FILE = "config.ini"
 
@@ -45,6 +45,11 @@ def from_dict(obj, data, replace=False):
         return replace_dataclass(obj, **fields)
 
 
+def to_dict(obj):
+    fields = asdict(obj)
+    return fields
+
+
 def save(obj, path="", unrepr=True, overwrite=False):
     path = locate(
         file=obj._file, paths=obj._paths, auto=obj._auto, file_path=path
@@ -65,7 +70,7 @@ def click_option(obj, *param_decls, **attrs):
         attrs.setdefault("is_eager", True)
         attrs.setdefault("help", "Read configuration from FILE")
         attrs.setdefault("expose_value", False)
-        path = attrs.pop("path", DEFAULT_FILE)
+        path = attrs.pop("path", obj._file)
         attrs["callback"] = partial(_file_option_callback, obj, path=path)
         config_update_option = click.option(
             "--config-update",
@@ -82,8 +87,8 @@ def click_option(obj, *param_decls, **attrs):
 def _file_option_callback(obj, ctx, option, value, path):
     ctx.default_map = ctx.default_map or {}
     path = value or path
-    obj.load(path=value)
-    options = asdict(obj)
+    obj.load(path=path)
+    options = obj.to_dict()
     ctx.default_map.update(options)
 
 
@@ -112,6 +117,7 @@ def dataconfig(
         setattr(cls, "load", load)
         setattr(cls, "save", save)
         setattr(cls, "from_dict", from_dict)
+        setattr(cls, "to_dict", to_dict)
         setattr(cls, "click_option", click_option)
         wrapped_cls = dataclass(
             cls,
